==> apache-polaris-1.2.0-incubating.tar.gz: apache-polaris-1.2.0-incubating/polaris-core/src/main/java/org/apache/polaris/core/catalog/ExternalCatalogFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.polaris.core.catalog;

import org.apache.iceberg.catalog.Catalog;
import org.apache.polaris.core.connection.ConnectionConfigInfoDpo;
import org.apache.polaris.core.secrets.UserSecretsManager;

/**
 * Factory interface for creating external catalog handles based on connection configuration.
 *
 * <p>Implementations should be annotated with CDI annotations and use the @Identifier annotation to
 * specify which connection type they support.
 */
public interface ExternalCatalogFactory {

  /**
   * Creates a catalog handle for the given connection configuration.
   *
   * @param connectionConfig the connection configuration
   * @param userSecretsManager the user secrets manager for handling credentials
   * @return the initialized catalog
   * @throws IllegalStateException if the connection configuration is invalid
   */
  Catalog createCatalog(
      ConnectionConfigInfoDpo connectionConfig, UserSecretsManager userSecretsManager);

  /**
   * Creates a generic table catalog for the given connection configuration.
   *
   * @param connectionConfig the connection configuration
   * @param userSecretsManager the user secrets manager for handling credentials
   * @return the initialized catalog
   * @throws IllegalStateException if the connection configuration is invalid
   */
  GenericTableCatalog createGenericCatalog(
      ConnectionConfigInfoDpo connectionConfig, UserSecretsManager userSecretsManager);
}

==> apache-polaris-1.3.0-incubating.tar.gz: apache-polaris-1.3.0-incubating/polaris-core/src/main/java/org/apache/polaris/core/catalog/ExternalCatalogFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.polaris.core.catalog;

import org.apache.iceberg.catalog.Catalog;
import org.apache.polaris.core.connection.ConnectionConfigInfoDpo;
import org.apache.polaris.core.credentials.PolarisCredentialManager;

/**
 * Factory interface for creating external catalog handles based on connection configuration.
 *
 * <p>Implementations should be annotated with CDI annotations and use the @Identifier annotation to
 * specify which connection type they support.
 */
public interface ExternalCatalogFactory {

  /**
   * Creates a catalog handle for the given connection configuration.
   *
   * @param connectionConfig the connection configuration
   * @param polarisCredentialManager the credential manager for generating connection credentials
   *     that Polaris uses to access external systems
   * @return the initialized catalog
   * @throws IllegalStateException if the connection configuration is invalid
   */
  Catalog createCatalog(
      ConnectionConfigInfoDpo connectionConfig, PolarisCredentialManager polarisCredentialManager);

  /**
   * Creates a generic table catalog for the given connection configuration.
   *
   * @param connectionConfig the connection configuration
   * @param polarisCredentialManager the credential manager for generating connection credentials
   *     that Polaris uses to access external systems
   * @return the initialized catalog
   * @throws IllegalStateException if the connection configuration is invalid
   */
  GenericTableCatalog createGenericCatalog(
      ConnectionConfigInfoDpo connectionConfig, PolarisCredentialManager polarisCredentialManager);
}
